from distutils.core import setup

setup(
    name = 'nester-reneb',
    version = '1.0.0',
    py_modules = ['nester'],
    author = 'Rene Bruggeman',
    author_email = 'bruggeman.rene@gmail.com',
    url = '',
    description = 'A simple printer of nested lists',
    )
